@@ -2,13 +2,24 @@
 #include "protocols/necprotocol.h"
 
 LogitechSpeakers::LogitechSpeakers(
-  QObject *guiObject,
   unsigned int index)
   : PIRKeysetMetaData(
       "Digital Speakers Keyset",
       Logitech_Make,
       index)
 {
+}
+
+
+void LogitechSpeakers::populateProtocol(
+  QObject *guiObject)
+{
+  if (threadableProtocol)
+  {
+    // If the pointer is not null, the keyset must already be populated.
+    return;
+  }
+
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
   setPreData(0x08, 8);
