@@ -9,64 +9,80 @@ class SanyoVCR1: public PIRKeysetMetaData
 {
 public:
   SanyoVCR1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoDVD1: public PIRKeysetMetaData
 {
 public:
   SanyoDVD1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoTV1: public PIRKeysetMetaData
 {
 public:
   SanyoTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoTV1a: public SanyoTV1
 {
 public:
   SanyoTV1a(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoTV1b: public SanyoTV1
 {
 public:
   SanyoTV1b(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoTV1c: public SanyoTV1a
 {
 public:
   SanyoTV1c(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoTV1d: public SanyoTV1
 {
 public:
   SanyoTV1d(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class SanyoProjector: public PIRKeysetMetaData
 {
 public:
   SanyoProjector(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // SANYO_H
