@@ -28,6 +28,7 @@ enum PIRMakeName{
   Hauppauge_Make,
   Hitachi_Make,
   Homecast_Make,
+  HP_Make,
   Huawei_Make,
   JVC_Make,
   Kenwood_Make,
@@ -36,6 +37,7 @@ enum PIRMakeName{
   Magnavox_Make,
   Microsoft_Make,
   Mitsubishi_Make,
+  Motorola_Make,
   Nokia_Make,
   Onida_Make,
   Panasonic_Make,
